jsvalue

package
v0.1.0-alpha.58 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 29, 2026 License: MIT Imports: 6 Imported by: 0

Documentation

Overview

Package jsvalue validates values before Go renders and JSON serializes them for the pinned JavaScript runtime.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Validate

func Validate(value any) error

Validate rejects Go values whose JSON representation cannot preserve the same observable value in JavaScript. Nil collections are rejected because generated array/object contracts expose collections, not null.

Types

This section is empty.

Jump to